XML_NAMESPACE = "http://www.w3.org/XML/1998/namespace"
XHTML_NAMESPACE = "http://www.w3.org/1999/xhtml"
XLINK_NAMESPACE = "http://www.w3.org/1999/xlink"
DSIG_NAMESPACE = "http://www.w3.org/2000/09/xmldsig#"
XSD_NAMESPACE = "http://www.w3.org/2001/XMLSchema"
XSI_NAMESPACE = "http://www.w3.org/2001/XMLSchema-Instance"

CATALOG_NAMESPACE = "urn:oasis:names:tc:entity:xmlns:xml:catalog"
DC_NAMESPACE = "http://purl.org/dc/elements/1.1/"
